@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2025 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20250920.1803
-;; Package-Revision: 89e009898dca
+;; Package-Version: 20251103.1432
+;; Package-Revision: 442202e59d61
 ;; URL: https://github.com/jamescherti/inhibit-mouse.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "24.1"))
@@ -183,7 +183,7 @@ Used in `input-decode-map' for disabled keys."
 
 ;;;###autoload
 (define-minor-mode inhibit-mouse-mode
-  "Toggle `inhibit-mouse-mode'."
+  "Disable all mouse input."
   :global t
   :lighter inhibit-mouse-mode-lighter
   :group 'inhibit-mouse
